#include <Fl/fl_ask.h>

#include "aniUI.h"
#include "aniDoc.h"

#include "dl.h"

#include "modeler.h"

#include "object.h"

#include "CurveEditor.h"

CurveEditor *curve_editor;

// global variables
CAniDoc* aniDoc;
CAniUI*  aniUI;

lpSetDrawModeFunc setDrawMode;

Object *objTable[MAX_OBJECTS];

static int id=-1;

// hopefully, MAX_OBJECTS is enough for most scenes
int getUniqueID()
{
	// we disable multiple objects
	return 0;
/*
	id=(id+1)%MAX_OBJECTS;

	return id;
*/
}

void addObject(int id, Object *obj)
{
	objTable[id]=obj;
}

void redrawScene()
{
	if (aniDoc->getScene())
		aniDoc->getScene()->refresh();
}

int main(int argc, char *argv[]) {
// load in DLL and do the necessary bindings
#ifdef WIN32
	char dlname[64]="modeler.dll";
#else
	char dlname[64]="libmodeler.so";
#endif

	if (argc>=2) {
		strcpy(dlname, argv[1]);
	}

	DLHANDLE hdl;
	hdl=DL_OpenLibrary(dlname);
	if (hdl==NULL) {
		fl_alert("Can't load %s", dlname);
		return 0;
	}

	setDrawMode=(lpSetDrawModeFunc)DL_BindFunction(hdl, "setdrawmode");
	if (setDrawMode==NULL) {
		fl_alert("Can't bind setDrawMode");
		return 0;
	}

	curve_editor=new CurveEditor();

	aniUI=new CAniUI;
	aniDoc=new CAniDoc;

	aniUI->setDocument(aniDoc);
	aniDoc->setUI(aniUI);

	Fl::visual(FL_DOUBLE|FL_INDEX);

	aniUI->show();

	if (argc >= 3) {
		strcpy(dlname, argv[2]);
		aniUI->load_named_object(aniUI,aniDoc,dlname);
	}
	else
		aniUI->load_named_object(aniUI,aniDoc,"mymodel.dll");

	if(argc >= 4) {
		strcpy(dlname, argv[3]);
		aniUI->load_named_ani(dlname);
	}
	else
		aniUI->load_named_ani("myanim.anm");

	int r=Fl::run();

	DL_CloseLibrary(hdl);

	return r;
}
